@@ -14,6 +14,7 @@
 #' }
 #' @param type of variables to summarize: "numeric" or "categorical" (character)
 #'
+#' @template options
 #' @examples
 #'
 #' \dontrun{
@@ -164,7 +165,7 @@ datasummary_skim_numeric <- function(
 
     # interactive or Rmarkdown/knitr
     } else {
-      if (check_dependency("knitr")) {
+      if (isTRUE(check_dependency("knitr"))) {
         if (!settings_equal("output_format", c("default", "html", "kableExtra")) && !knitr::is_latex_output()) {
           histogram <- FALSE
         }
