@@ -43,13 +43,12 @@ factory_kableExtra <- function(tab,
   arguments$escape <- FALSE
 
   ## siunitx in preamble
-  if (settings_equal("format_numeric_latex", "siunitx")) {
-      invisible(
-        knitr::knit_meta_add(list(
-          rmarkdown::latex_dependency("booktabs"))))
-      invisible(knitr::knit_meta_add(list(
-          rmarkdown::latex_dependency("siunitx", extra_lines = "\\newcolumntype{d}{S[input-symbols = ()]}")
-      )))
+  if (settings_equal("output_format", c("latex", "latex_tabular")) &&
+      settings_equal("format_numeric_latex", "siunitx")) {
+    invisible(knitr::knit_meta_add(list(
+      rmarkdown::latex_dependency("booktabs"))))
+    invisible(knitr::knit_meta_add(list(
+      rmarkdown::latex_dependency("siunitx", extra_lines = "\\newcolumntype{d}{S[input-symbols = ()]}"))))
   }
 
   ## align
